package de.intevation.flys.artifacts.model;

import java.util.List;

import org.apache.log4j.Logger;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;
import de.intevation.artifacts.DataProvider;

import de.intevation.artifactdatabase.state.Facet;

import de.intevation.flys.artifacts.HYKArtifact;

import de.intevation.flys.artifacts.states.DefaultState.ComputeType;
import de.intevation.flys.model.FastCrossSectionLine;


/**
 * Trival Facet for HYKs
 */
public class HYKFacet
extends      DataFacet
implements   FacetTypes {

    /** House logger. */
    private static Logger logger = Logger.getLogger(HYKFacet.class);


    /** Trivial constructor, set (maybe localized) description. */
    public HYKFacet(int idx, String description) {
        super(idx, HYK, description, ComputeType.FEED, null, null);
    }


    /**
     * Set km from cross section- master to HYKArtifact, then fire up
     * computation.
     *
     * @param art artifact to get data from.
     * @param context ignored
     */
     public Object getData(Artifact art, CallContext context) {
        logger.debug("HYKFacet.getData");

        String dataKey = CrossSectionFacet.BLACKBOARD_CS_MASTER_DATA;

        List<DataProvider> providers = context.getDataProvider(dataKey);
        if (providers.size() < 1) {
            logger.warn("Could not find Cross-Section data provider to get master cs km.");
            return null;
        }
                        
        FastCrossSectionLine crossSection = (FastCrossSectionLine) providers.get(0)
            .provideData(dataKey, null, context);

        double km = crossSection.getKm();
        logger.debug("HYKFacet.getData: Master Cross Section is at km: " + km);

        // Set this km at hyk artifact to be evaluated.
        HYKArtifact hyk = (HYKArtifact) art;
        hyk.setKm(km);

        return hyk.compute(context, hash, stateId, type, false);
    }


    /** Do a deep copy. */
    @Override 
    public Facet deepCopy() {
        HYKFacet copy = new HYKFacet(this.index, this.description);
        copy.set(this);
        return copy;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
